@@ -1,4 +1,7 @@
 package Server::Control::HTTPServerSimple;
+BEGIN {
+  $Server::Control::HTTPServerSimple::VERSION = '0.15';
+}
 use Carp;
 use Moose;
 use MooseX::StrictConstructor;
@@ -9,13 +12,9 @@ use warnings;
 
 extends 'Server::Control';
 
-has 'server_class' => (
-    is       => 'ro',
-    required => 1
-);
-has 'server' => ( is => 'ro', lazy_build => 1 );
-has 'net_server_params' =>
-  ( is => 'ro', isa => 'HashRef', default => sub { {} } );
+has 'net_server_params' => ( is => 'ro', isa => 'HashRef', default => sub { {} } );
+has 'server'            => ( is => 'ro', lazy_build => 1 );
+has 'server_class'      => ( is => 'ro', required => 1 );
 
 __PACKAGE__->meta->make_immutable();
 
@@ -61,7 +60,7 @@ sub do_start {
 
 1;
 
-__END__
+
 
 =pod
 
@@ -70,6 +69,10 @@ __END__
 Server::Control::HTTPServerSimple -- apachectl style control for
 HTTP::Server::Simple servers
 
+=head1 VERSION
+
+version 0.15
+
 =head1 SYNOPSIS
 
     package My::Server;
@@ -131,24 +134,20 @@ L</net_server_params>.
 
 =back
 
-=head1 AUTHOR
-
-Jonathan Swartz
-
 =head1 SEE ALSO
 
 L<Server::Control|Server::Control>,
 L<HTTP::Server::Simple|HTTP::Server::Simple>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2007 Jonathan Swartz.
+This software is copyright (c) 2011 by Jonathan Swartz.
 
-Server::Control::Apache is provided "as is" and without any express or implied
-warranties, including, without limitation, the implied warranties of
-merchantibility and fitness for a particular purpose.
-
-This program is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
